
.. _user:

#################
Numina User Guide
#################

This guide is intended as an introductory overview of Numina and
explains how to install and make use of the most important features. For
detailed reference documentation of the functions and
classes contained in the package, see the :ref:`reference`.

.. warning::

   This "User Guide" is still a work in progress; some of the material
   is not organized, and several aspects of Numina are not yet covered
   sufficient detail.

.. toctree::
   :maxdepth: 2

   intro
   deploy
   solaris
   cli
